@@ -31,18 +31,9 @@
 #' highlights the individual responsible for the overlap using a color code. The width of the polygons 
 #' depicting the time of overlap. 
 #' @examples{
-#' 
-#' # First set temporary folder
-#' # setwd(tempdir())
-#' 
 #' # load simulate singing events  (see data documentation)
 #' data(sim.coor.sing)
 #' 
-#' # make coor.graphs in tiff format
-#' coor.graph(X = sim.coor.sing, ovlp = TRUE, only.coor = FALSE, xl =2, res =80, 
-#' it = "tiff", img = TRUE)
-#'
-#'
 #'#' # make coor.graphs in graphic device format
 #'cgs <- coor.graph(X = sim.coor.sing, ovlp = TRUE, only.coor = FALSE, img = FALSE)
 #' 
@@ -50,7 +41,7 @@
 #' }
 #' 
 #' @references {Araya-Salas, M., & Smith-Vidaurre, G. (2017). warbleR: An R package to streamline analysis of animal acoustic signals. Methods in Ecology and Evolution, 8(2), 184-191.}
-#' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu})
+#' @author Marcelo Araya-Salas (\email{marceloa27@@gmail.com})
 #last modification on aug-13-2016 (MAS)
 
 coor.graph <- function(X = NULL, only.coor = FALSE, ovlp = TRUE, xl = 1,  res= 80, it = "jpeg",
@@ -102,12 +93,9 @@ coor.graph <- function(X = NULL, only.coor = FALSE, ovlp = TRUE, xl = 1,  res= 8
     
     #stop if some events do not have 2 individuals 
     qw <- as.data.frame((tapply(X$sing.event, list(X$sing.event, X$indiv), length)))
-  
-  qw[qw > 0] <- 1
-  
-  if (any(apply(qw, 1, sum) != 2)) stop("Some singing events don't have 2 interating individuals ('indiv' colum)")
-  
-  
+    qw <- tapply(X$indiv, X$sing.event, function(x) length(unique(x)))
+    
+  if (any(qw != 2)) stop("Some singing events don't have 2 interacting individuals ('indiv' column)")
   
   #if xl is not vector or length!=1 stop
   if (is.null(xl)) stop("'xl' must be a numeric vector of length 1") else {
