@@ -1,19 +1,16 @@
 #' Convert .mp3 files to .wav
 #' 
 #' \code{mp32wav} converts several .mp3 files in working directory to .wav format
-#' @usage mp32wav(samp.rate = 44.1, parallel = 1, path = NULL, 
-#' to = NULL, dest.path = NULL, bit.depth = 16, pb = TRUE, overwrite = FALSE)  
-#' @param samp.rate Sampling rate at which the .wav files should be written. The maximum permitted is 44.1 kHz (default). 
-#' Units should be kHz. If not provided the sample rate of the original .mp3 file is used. Downsampling is done using the
-#' \code{\link[tuneR]{downsample}} function from tuneR, which seems to generate aliasing. This can be avoided by downsampling after .mp3's have been converted using the \code{\link{fix_wavs}} function (which uses SOX instead).  
+#' @usage mp32wav(samp.rate = NULL, parallel = 1, path = NULL, 
+#'  dest.path = NULL, bit.depth = 16, pb = TRUE, overwrite = FALSE)  
+#' @param samp.rate Sampling rate in kHz at which the .wav files should be written. If not provided the sample rate of the original .mp3 file is used. Downsampling is done using the
+#' \code{\link[bioacoustics]{resample}} function from the \href{https://cran.r-project.org/package=bioacoustics}{bioacoustics package} (which should be installed), which seems to generate aliasing. This can be avoided by downsampling after .mp3's have been converted using the \code{\link{fix_wavs}} function (which uses \href{http://sox.sourceforge.net/sox.html}{SOX} instead). Default is \code{NULL} (e.g. keep original sampling rate).
 #' @param parallel Numeric. Controls whether parallel computing is applied. 
 #'  It specifies the number of cores to be used. Default is 1 (i.e. no parallel computing).
 #' @param path Character string containing the directory path where the .mp3 files are located.   
 #' If \code{NULL} (default) then the current working directory is used. 
-#' @param to Character string containing the directory path where the .wav files will be saved. 
-#' If \code{NULL} (default) then the current working directory is used. Will be deprecated in future versions.
 #' @param dest.path Character string containing the directory path where the .wav files will be saved. 
-#' If \code{NULL} (default) then the current working directory is used. Same as 'to' (will replace it in future versions).
+#' If \code{NULL} (default) then the folder containing the sound files will be used. 
 #' @param bit.depth Character string containing the units to be used for amplitude normalization. Check 
 #' \code{\link[tuneR]{normalize}} for details. Default is 16.
 #' @param pb Logical argument to control progress bar. Default is \code{TRUE}.
@@ -21,35 +18,33 @@
 #' overwritten.
 #' @return .wav files saved in the working directory with same name as original mp3 files.
 #' @export
+#' @details The function will convert all mp3 files in  working directory or 'path' supplied to wav format. \href{https://cran.r-project.org/package=bioacoustics}{bioacoustics package} must be installed when changing sampling rates (i.e. if 'samp.rate' is supplied). Note that sound files are normalized using \code{\link[tuneR]{normalize}} so they can be written by \code{\link[tuneR]{writeWave}}.
 #' @name mp32wav
 #' @examples
 #' \dontrun{
-#' # First set temporary folder
-#' # setwd(tempdir())
-#'  
-#' #Then download mp3 files from xeno-canto
-#' querxc(qword = "Phaethornis aethopygus", download = TRUE)
+#' # download mp3 files from xeno-canto
+#' querxc(qword = "Phaethornis aethopygus", download = TRUE, path = tempdir())
 #' 
 #' # Convert all files to .wav format
-#' mp32wav()
+#' mp32wav(path = tempdir(), dest.path = tempdir())
 #' 
 #' #check this folder!!
-#' getwd()
+#' tempdir()
 #' }
 #' 
 #' @references {
 #' Araya-Salas, M., & Smith-Vidaurre, G. (2017). warbleR: An R package to streamline analysis of animal acoustic signals. Methods in Ecology and Evolution, 8(2), 184-191.
 #' }
 #' @details convert all .mp3 files in working directory to .wav format. Function used internally to read .mp3 files (\code{\link[tuneR]{readMP3}}) sometimes crashes.
-#' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu}) and Grace Smith Vidaurre
+#' @author Marcelo Araya-Salas (\email{marceloa27@@gmail.com}) and Grace Smith Vidaurre
 #last modification on mar-13-2018 (MAS)
 
-mp32wav <- function(samp.rate = 44.1, parallel = 1, path = NULL, 
-                    to = NULL, dest.path = NULL, bit.depth = 16, pb = TRUE, overwrite = FALSE) {
+mp32wav <- function(samp.rate = NULL, parallel = 1, path = NULL, 
+                  dest.path = NULL, bit.depth = 16, pb = TRUE, overwrite = FALSE) {
   
-  # reset working directory 
-  wd <- getwd()
-  on.exit(setwd(wd))
+  # error message if bioacoustics is not installed
+  if (!requireNamespace("bioacoustics", quietly = TRUE) & !is.null(samp.rate))
+    stop("must install 'bioacoustics' to use mp32wav() for changing sampling rate")
   
   # set pb options 
   on.exit(pbapply::pboptions(type = .Options$pboptions$type), add = TRUE)
@@ -80,13 +75,11 @@ mp32wav <- function(samp.rate = 44.1, parallel = 1, path = NULL,
   
   if (!is.null(path))
   {if (!dir.exists(path)) stop("'path' provided does not exist")} else
-    path <- wd #set working directory
-
-  setwd(path)
+    path <- getwd() 
   
-  if (!is.null(to))
-  {if (!dir.exists(to)) stop("'path' provided does not exist")} else
-    to <- wd #set working directory
+  if (!is.null(dest.path))
+  {if (!dir.exists(dest.path)) stop("'path' provided does not exist")} else
+    dest.path <- path #set working directory
   
   #normalize
   if (length(bit.depth) > 1) stop("'bit.depth' should have a single value")
@@ -98,13 +91,12 @@ mp32wav <- function(samp.rate = 44.1, parallel = 1, path = NULL,
   if (!is.numeric(parallel)) stop("'parallel' must be a numeric vector of length 1") 
   if (any(!(parallel %% 1 == 0),parallel < 1)) stop("'parallel' should be a positive integer")
           
-  files <- list.files(path=getwd(), pattern = ".mp3$", ignore.case = TRUE) #list .mp3 files in working directory
+  files <- list.files(path = path, pattern = ".mp3$", ignore.case = TRUE) #list .mp3 files in working directory
   if (length(files) == 0) stop("no 'mp3' files in working directory")
   
   #exclude the ones that already have a .wav version
- 
-  if (!overwrite) 
-    {wavs <- list.files(pattern = "\\.wav$", ignore.case = TRUE)
+  if (!overwrite) {
+    wavs <- list.files(path = dest.path, pattern = "\\.wav$", ignore.case = TRUE)
   files <- files[!substr(files, 0, nchar(files) - 4) %in% substr(wavs, 0, nchar(wavs) - 4)]
   if (length(files) == 0) stop("all 'mp3' files have been converted")
   }
@@ -113,10 +105,10 @@ mp32wav <- function(samp.rate = 44.1, parallel = 1, path = NULL,
  mp3_conv_FUN <- function(x, bit.depth) {
    
    # read mp3
-   wv <- try(tuneR::readMP3(filename =  x), silent = TRUE)
+   wv <- try(tuneR::readMP3(filename =  file.path(path, x)), silent = TRUE)
    
    # downsample and filter if samp.rate different than mp3
-   if(class(wv) == "Wave")
+   if(class(wv) == "Wave" & !is.null(samp.rate))
    {
      if (wv@samp.rate != samp.rate * 1000) {
       
@@ -129,13 +121,13 @@ mp32wav <- function(samp.rate = 44.1, parallel = 1, path = NULL,
       }
 
     # normalize 
-     if (bit.depth != wv@bit)
        wv <- tuneR::normalize(object = wv, unit = as.character(bit.depth))
      
-   wv <- try(tuneR::writeWave(extensible = FALSE, object = wv, filename = file.path(path, paste0(substr(x, 0, nchar(x) - 4), ".wav"))), silent = TRUE)
-   }
+     }
    
-   return(wv)
+   wv <- try(tuneR::writeWave(extensible = FALSE, object = wv, filename = file.path(path, paste0(substr(x, 0, nchar(x) - 4), ".wav"))), silent = TRUE)
+   
+   return(NULL)
    }
 
  # set pb options 
