@@ -1,7 +1,7 @@
 #' Add spectrograms onto phylogenetic trees
 #' 
 #' \code{phylo_spectro} Add spectrograms to the tips of an objects of class phylo.
-#' @usage phylo_spectro(X, tree, type = "fan", par.mar = rep(1, 4), 
+#' @usage phylo_spectro(X, tree, type = "phylogram", par.mar = rep(1, 4), 
 #' size = 1, offset = 0, path = NULL, ladder = NULL, horizontal = TRUE, ...) 
 #' @param X 'selection_table', 'extended_selection_table' or data frame containing columns for sound file name 
 #' (sound.files), selection number (selec), and start and end time of signals (start and end). 
@@ -35,23 +35,23 @@
 #' @details The function add the spectrograms of sounds annotated in a selection table ('X' argument) onto the tips of a phylogenetic tree. 
 #' The 'tip.label' column in 'X' is used to match spectrograms and tree tips. The function uses internally the \code{\link[ape]{plot.phylo}} function to plot the tree 
 #' and the \code{\link{specreator}} function to create the spectrograms. Arguments for both of these functions
-#' can be provided for further customization. Fitting spectrograms  
+#' can be provided for further customization.
 #' @examples { 
 #' \donttest{
 #' # First set empty folder
-#' # setwd(tempdir())
+#' 
 #' 
 #' # save example sound files
-#' data(list = c("Phae.long1", "Phae.long2", "Phae.long3", "selec.table"))
-#' writeWave(Phae.long1,"Phae.long1.wav")
-#' writeWave(Phae.long2,"Phae.long2.wav")
-#' writeWave(Phae.long3,"Phae.long3.wav")
+#' data(list = c("Phae.long1", "Phae.long2", "Phae.long3", "lbh_selec_table"))
+#' writeWave(Phae.long1, file.path(tempdir(), "Phae.long1.wav"))
+#' writeWave(Phae.long2, file.path(tempdir(), "Phae.long2.wav"))
+#' writeWave(Phae.long3, file.path(tempdir(), "Phae.long3.wav"))
 #' 
 #' # set spectrogram options (can be done at the phylo_spectro() function too)
-#' warbleR_options(wl = 200, ovlp = 90, flim = "frange")
+#' warbleR_options(wl = 200, ovlp = 90, flim = "frange", wav.path = tempdir())
 #' 
 #' # subset example selection table
-#' X <- selec.table[1:8, ]
+#' X <- lbh_selec_table[1:8, ]
 #' 
 #' # create random tree (need ape to be installed)
 #' set.seed(1)
@@ -93,10 +93,10 @@
 #' @references {
 #' Araya-Salas, M., & Smith-Vidaurre, G. (2017). warbleR: An R package to streamline analysis of animal acoustic signals. Methods in Ecology and Evolution, 8(2), 184-191.
 #' }
-#' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu})
+#' @author Marcelo Araya-Salas (\email{marceloa27@@gmail.com})
 #last modification on oct-1-2018 (MAS)
 
-phylo_spectro <- function(X, tree, type = "fan", par.mar = rep(1, 4), size = 1, offset = 0, 
+phylo_spectro <- function(X, tree, type = "phylogram", par.mar = rep(1, 4), size = 1, offset = 0, 
                          path = NULL, ladder = NULL, horizontal = TRUE, ...) {
 
   # error message if ape is not installed
@@ -104,19 +104,16 @@ phylo_spectro <- function(X, tree, type = "fan", par.mar = rep(1, 4), size = 1,
     stop("must install 'ape' to use phylo_spectro()")
   
   # currenlt only horizontal is allowed
+  if (!horizontal) cat("Currently only horizontal spectrograms are allowed")
   horizontal <- TRUE
   
-  ## save curent working directory and use a temporary one for saving images
-  wd <- getwd() # save
-  on.exit(setwd(wd), add = TRUE) # restores directory at the end
-  if (is.null(path)) path <- wd # set  directory
-  
-  # set temporary working directory to save images  
-  setwd(path)
+  #check path if not provided set to working directory
+  if (is.null(path)) path <- getwd() else 
+    if (!dir.exists(path)) stop("'path' provided does not exist") 
   
   ## save par current setting and restores it later
   opar <- par # save
-  on.exit(opar, add = TRUE) # restore
+  on.exit(opar) # restore
   
   #### set arguments from options
   # get function arguments
@@ -148,7 +145,10 @@ phylo_spectro <- function(X, tree, type = "fan", par.mar = rep(1, 4), size = 1,
  # check tip labels match
  if (!identical(sort(as.character(X$tip.label)), sort(tree$tip.label))) stop("tree tip labels (tree$tip.label) and 'tip.label' column in 'X' do not match")
  
- # map arguments provided
+  #sort X as in tip labels
+  X <- X[match(tree$tip.label, X$tip.label), ]
+
+  # map arguments provided
  argus <- c(opt.argms, call.argms)
  
  ## SPECTROGRAMS (save in temporary directory)  
@@ -194,16 +194,23 @@ phylo_spectro <- function(X, tree, type = "fan", par.mar = rep(1, 4), size = 1,
   
   # get border coordinates
   usr <- par()$usr
-  plt <- par()$plt
-
-  # correct for margins
-  usr <- usr * (abs(plt - c(0, 1, 0, 1)) + 1)
+  # plt <- par()$plt
+  # 
+  # # correct for margins
+  # usr[2] <- usr[2] + ((usr[2] - usr[1]) * (1 - plt[2])) 
+  # usr[1] <- usr[1] - ((usr[2] - usr[1]) * plt[1])
 
+  # y limits
+  plt.y.rng <- usr[4] - usr[3]
+  
+  # fix size according to number of tips in tree
+  size <- plt.y.rng / nrow(X) * size 
+  
   # get coordinates for spectrograms
   lastPP <- get("last_plot.phylo", envir = ape::.PlotPhyloEnv)
   xs <- lastPP$xx[1:nrow(X)]
   ys <- lastPP$yy[1:nrow(X)]
-  
+
    # fix offset (taken from ape::tiplabels)
   if (offset != 0) {
     if (lastPP$type %in% c("phylogram", "cladogram")) {
@@ -229,9 +236,6 @@ phylo_spectro <- function(X, tree, type = "fan", par.mar = rep(1, 4), size = 1,
   # get degrees
   dgs <- rep(0, length(xs))
   
-  # fix size according to number of tips in tree
-  size <- size / sqrt(nrow(X))
-  
   # if position of  not horizontal
   if (!horizontal & lastPP$type %in% c("fan", "radial"))
   {
@@ -259,49 +263,35 @@ phylo_spectro <- function(X, tree, type = "fan", par.mar = rep(1, 4), size = 1,
   for(y in 1:nrow(X)) {
     
     # read images    
-    imgs[[1 + length(imgs)]] <- jpeg::readJPEG(source = file.path(tempdir(), paste0(X$sound.files[y], "-", X$selec[y], ".jpeg")))
+    imgs[[1 + length(imgs)]] <- jpeg::readJPEG(source = file.path(tempdir(),  paste0(X$sound.files[y], "-", X$selec[y], ".jpeg")))
     
     # get image dimensions
     dims <- dim(imgs[[length(imgs)]])
     
     # get image aspect
     coors$asp[y] <- 1 / (dims[1] / dims[2])
-    
-    # allow to plot outside main image area
-    par(xpd = TRUE, mar = par()$mar + c(0, 0, 0, 7))
-    
+  
     # calculate image limits
-    if (lastPP$type == "phylogram") 
+    # if (lastPP$type == "phylogram") 
    
-    coors$xleft[y] <- xs[y]  
-    coors$xright[y] <- xs[y] + size  * coors$asp[y]  
+    coors$xleft[y] <- coors$xs[y]  
+    coors$xright[y] <- coors$xs[y] + size  * coors$asp[y]  
+    coors$difx[y] <- size  * coors$asp[y]  
     coors$ybottom[y] <- coors$ys[y] - (size / 2)  
     coors$ytop[y] <- coors$ys[y] + (size / 2)  
-  }
+      }
 
-  # fix right margin
-  if (lastPP$direction == "rightwards")
-   coors$xright <- coors$xright * (usr[2]/max(coors$xright))
-  
-  # allow to plot outside main image area
-  par(xpd = TRUE, mar = par()$mar + c(0, 0, 0, 7))
-  
   # add spectros to phylogeny  
   for(y in 1:nrow(X)) {
 
+    # allow to plot outside main image area
+    par(xpd = TRUE)
+    
     # add spectrograms
     if (lastPP$type == "phylogram")
-    graphics::rasterImage(image = imgs[[y]], xleft = coors$xleft[y], ybottom = coors$ybottom[y], xright = coors$xright[y], ytop = coors$ytop[y], angle = dgs[y])     else
+    graphics::rasterImage(image = imgs[[y]], xleft = coors$xleft[y], ybottom = coors$ybottom[y], xright = coors$xleft[y] +  coors$difx[y], ytop = coors$ytop[y], angle = dgs[y])
+    else
     graphics::rasterImage(image = imgs[[y]], xleft = xs[y] - (size / 2), ybottom = ys[y] - (size / 2  * coors$asp[y]), xright = xs[y] + (size / 2), ytop = ys[y] + (size * coors$asp[y] / 2), angle = dgs[y])
   }
 
-  
-  # add points to coordinates for each label
-  # points(x = xs, y = ys, pch = 20, col = "purple")
-  
-  # add labels to check degrees
-  # for( i in 1:nrow(X))
-  # text(x = xs[i], y = ys[i], cex =2 , labels = "text" , col = "green", srt = dgs[i])
-  
-# return(cbind(xs, ys, dgs))
   }
